==> estateplat-common-1.2.4-20220914.091730-1094-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslJfjgLog.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:xusong@gtmap.cn">xusong</a>
 * @version 1.0, 2022/8/4
 * @description 缴款结果记录
 */
@Table( name ="YCSL_JFJG_LOG" )
public class YcslJfjgLog {
    /**
     * 主键
     */
    @Column(name = "log_id" )
    @Id
    private String logid;

    /**
     * 与项目表关联
     */
    @Column(name = "proid" )
    private String proid;

    /**
     * 权利人类型
     */
    @Column(name = "qlrlx" )
    private String qlrlx;


    /**
     * 缴费类型
     */
    @Column(name = "jflx" )
    private String jflx;


    /**
     * 缴费状态
     */
    @Column(name = "jfzt" )
    private String jfzt;


    /**
     * 缴款连接
     */
    @Column(name = "url" )
    private String url;

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}

==> estateplat-common-1.2.4-20241107.014146-1268-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslJfjgLog.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:xusong@gtmap.cn">xusong</a>
 * @version 1.0, 2022/8/4
 * @description 缴款结果记录
 */
@Table( name ="YCSL_JFJG_LOG" )
public class YcslJfjgLog {
    /**
     * 主键
     */
    @Column(name = "log_id" )
    @Id
    private String logid;

    /**
     * 与项目表关联
     */
    @Column(name = "proid" )
    private String proid;

    /**
     * 权利人类型
     */
    @Column(name = "qlrlx" )
    private String qlrlx;


    /**
     * 缴费类型
     */
    @Column(name = "jflx" )
    private String jflx;


    /**
     * 缴费状态
     */
    @Column(name = "jfzt" )
    private String jfzt;


    /**
     * 缴款连接
     */
    @Column(name = "url" )
    private String url;

    /**
     * 更新时间
     */
    @Column(name = "updatetime" )
    private Date updatetime;


    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}
